name = "Suluoya"
version = '1.4.4'
author = 'Suluoya'
author_email = '1931960436@qq.com'
qq = '1931960436'
phone_number = '18971672030'
__all__ = ['sly']
from .sly import *
def welcome():
    print('Welcome to use Suluoya!')



